==> web-7.0.0.tgz: package/lib/menu/ParMenu.js <==
import * as React from "react";
import { SvgIcon } from "../my-icon/index";
import { NavLink } from "react-router-dom";
import * as Velocity from "velocity-react";
class ParMenu extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = {
            drop: true
        };
        this.toggleSlide = () => {
            this.setState(pre => ({
                drop: !pre.drop
            }));
        };
        this.selectItemFn = (e) => {
            const dom = e.currentTarget;
            const index = dom.dataset.index;
            const indexArr = index.split(",");
            const { changeData } = this.props;
            changeData(function (_data, selected) {
                const oldSelectedArr = selected.split(",");
                let data = _data;
                if (oldSelectedArr.length === 2) {
                    data = data.updateIn([oldSelectedArr[0]], (node) => {
                        return node.set("selected", false).updateIn(["children", oldSelectedArr[1]], (item) => {
                            return item.set("selected", false);
                        });
                    });
                }
                data = data.updateIn([indexArr[0]], (node) => {
                    return node.set("selected", true).updateIn(["children", indexArr[1]], (item) => {
                        return item.set("selected", true);
                    });
                });
                return {
                    data,
                    selected: index
                };
            });
        };
    }
    subMenu(children, parIndex) {
        const { fieldObj } = this.props;
        const idField = fieldObj.get("id");
        const textField = fieldObj.get("text");
        const urlField = fieldObj.get("url");
        return children.map((node, index) => {
            const id = node.get(idField);
            const text = node.get(textField);
            const activeName = node.get("selected") ? "active" : "";
            const url = node.get(urlField);
            const typeId = node.get("type") || "";
            const pathObj = {
                pathname: url,
                state: {
                    typeId: `${typeId}`,
                    text,
                }
            };
            return (React.createElement("li", { className: "li-child", key: id },
                React.createElement("div", { className: `menu-item menu-child ${activeName}` },
                    React.createElement("span", { className: "j-nav", "data-index": `${parIndex},${index}`, onClick: this.selectItemFn },
                        React.createElement(NavLink, { to: pathObj, replace: true }, text)))));
        });
    }
    getSubCom() {
        const { node, expand, parIndex } = this.props;
        const child = node.get("children");
        const subCom = (React.createElement("ul", { className: "child-ul" }, this.subMenu(child, parIndex)));
        return expand ? (React.createElement(Velocity.VelocityComponent, { animation: this.state.drop ? "slideDown" : "slideUp", duration: 300, interruptBehavior: "queue" }, subCom)) : subCom;
    }
    render() {
        const { node, fieldObj, expand } = this.props;
        const { drop } = this.state;
        const activeName = node.get("selected") ? "active" : "";
        const icon = node.get(fieldObj.get("icon"));
        const text = node.get(fieldObj.get("text"));
        const sub = this.getSubCom();
        return (React.createElement("li", { className: "li-par" },
            React.createElement("div", { className: `menu-item menu-par ${activeName}`, onClick: expand ? this.toggleSlide : undefined },
                React.createElement("span", { className: "par-icon" },
                    React.createElement(SvgIcon, { className: icon })),
                React.createElement("span", { className: "nav-text" }, text),
                React.createElement("span", { className: "m-slide-icon" },
                    React.createElement(SvgIcon, { className: `arrow-${drop ? "down" : "up"}` }))),
            sub));
    }
}
export default ParMenu;

==> web-8.0.0.tgz: package/lib/menu/ParMenu.js <==
import * as React from "react";
import { SvgIcon } from "../my-icon/index";
import { NavLink } from "react-router-dom";
import { SlideBox } from "../animate/index";
class ParMenu extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = {};
        this.selectItemFn = (e) => {
            const dom = e.currentTarget;
            const index = dom.dataset.index;
            const indexArr = index.split(",");
            const { changeData } = this.props;
            changeData(function (_data, selected) {
                const oldSelectedArr = selected.split(",");
                let data = _data;
                if (oldSelectedArr.length === 2) {
                    data = data.updateIn([oldSelectedArr[0]], (node) => {
                        return node.set("selected", false).updateIn(["children", oldSelectedArr[1]], (item) => {
                            return item.set("selected", false);
                        });
                    });
                }
                data = data.updateIn([indexArr[0]], (node) => {
                    return node.set("selected", true).updateIn(["children", indexArr[1]], (item) => {
                        return item.set("selected", true);
                    });
                });
                return {
                    data,
                    selected: index
                };
            });
        };
        this.toggleSlide = () => {
            this.props.toggleSlide(this.props.parIndex);
        };
    }
    subMenu(children, parIndex) {
        const { fieldObj } = this.props;
        const idField = fieldObj.get("id");
        const textField = fieldObj.get("text");
        const urlField = fieldObj.get("url");
        return children.map((node, index) => {
            const id = node.get(idField);
            const text = node.get(textField);
            const activeName = node.get("selected") ? "active" : "";
            const url = node.get(urlField);
            const typeId = node.get("type") || "";
            const pathObj = {
                pathname: url,
                state: {
                    typeId: `${typeId}`,
                    text,
                }
            };
            return (React.createElement("li", { className: "li-child", key: id },
                React.createElement("div", { className: `menu-item menu-child ${activeName}` },
                    React.createElement("span", { className: "j-nav", "data-index": `${parIndex},${index}`, onClick: this.selectItemFn },
                        React.createElement(NavLink, { to: pathObj, replace: true }, text)))));
        });
    }
    getSubCom() {
        const { node, expand, parIndex } = this.props;
        const child = node.get("children");
        const subCom = (React.createElement("ul", { className: "child-ul" }, this.subMenu(child, parIndex)));
        return expand ? (React.createElement(SlideBox, { slide: node.get("drop"), isImmedia: true }, subCom)) : subCom;
    }
    render() {
        const { node, fieldObj, expand } = this.props;
        const drop = node.get("drop");
        const activeName = node.get("selected") ? "active" : "";
        const icon = node.get(fieldObj.get("icon"));
        const text = node.get(fieldObj.get("text"));
        const sub = this.getSubCom();
        return (React.createElement("li", { className: "li-par" },
            React.createElement("div", { className: `menu-item menu-par ${activeName}`, onClick: expand ? this.toggleSlide : undefined },
                React.createElement("span", { className: "par-icon" },
                    React.createElement(SvgIcon, { className: icon })),
                React.createElement("span", { className: "nav-text" }, text),
                React.createElement("span", { className: "m-slide-icon" },
                    React.createElement(SvgIcon, { className: `arrow-${drop ? "down" : "up"}` }))),
            sub));
    }
}
export default ParMenu;
